CoreContentMatcher

Trait CoreContentMatcher 

pub trait CoreContentMatcher: Send + Sync {
    // Required method
    fn compare_contents<'life0, 'async_trait>(
        &'life0 self,
        request: CompareContentsRequest,
    ) -> Pin<Box<dyn Future<Output = Result<CompareContentsResponse>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
A host-provided handler for the CompareContents capability shape. Implemented by the embedding Pact framework and registered via register_core_content_matcher.

Required Methods

fn compare_contents<'life0, 'async_trait>( &'life0 self, request: CompareContentsRequest, ) -> Pin<Box<dyn Future<Output = Result<CompareContentsResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Compare the actual contents against the expected contents, returning any mismatches.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors