pub struct FieldGenerator {
pub catalogue_entry: CatalogueEntry,
}Expand description
Generator for a single field/element value. See FieldMatcher.
Fields
catalogue_entry: CatalogueEntryCatalogue entry for this generator
Implementations
Sourceimpl FieldGenerator
impl FieldGenerator
Sourcepub fn is_core(&self) -> bool
pub fn is_core(&self) -> bool
If this is a generator provided by the core framework rather than a plugin
Sourcepub fn catalogue_entry_key(&self) -> String
pub fn catalogue_entry_key(&self) -> String
Catalogue entry key for this generator
Sourcepub fn plugin(&self) -> Option<PactPluginManifest>
pub fn plugin(&self) -> Option<PactPluginManifest>
Plugin that provides this generator, if any
Sourcepub fn plugin_name(&self) -> String
pub fn plugin_name(&self) -> String
Name of the plugin that provides this generator
Sourcepub async fn generate_field(
&self,
generator: &Generator,
example: &FieldValue,
mode: TestMode,
context: &FieldContext,
) -> Result<FieldValue>
pub async fn generate_field( &self, generator: &Generator, example: &FieldValue, mode: TestMode, context: &FieldContext, ) -> Result<FieldValue>
Generate a single value, replacing the example value from the Pact interaction.
Sourcepub fn generate_field_blocking(
&self,
generator: &Generator,
example: &FieldValue,
mode: TestMode,
context: &FieldContext,
) -> Result<FieldValue>
pub fn generate_field_blocking( &self, generator: &Generator, example: &FieldValue, mode: TestMode, context: &FieldContext, ) -> Result<FieldValue>
Generate a single value from a synchronous call path. See
FieldMatcher::match_field_blocking.