pub fn set_plugin_log_sink(sink: Box<dyn PluginLogSink>)Expand description
Replace the active plugin log sink. Should be called once at startup before any plugins load.
pub fn set_plugin_log_sink(sink: Box<dyn PluginLogSink>)Replace the active plugin log sink. Should be called once at startup before any plugins load.