pub fn lookup_plugin(
plugin: &PluginDependency,
) -> Option<Arc<dyn PluginInstance + Send + Sync>>Expand description
Look up the plugin in the global plugin register
pub fn lookup_plugin(
plugin: &PluginDependency,
) -> Option<Arc<dyn PluginInstance + Send + Sync>>Look up the plugin in the global plugin register