pub fn lookup_plugin_manifest(
plugin: &PluginDependency,
) -> Option<PactPluginManifest>Expand description
Lookup the plugin manifest in the global plugin manifest registry.
pub fn lookup_plugin_manifest(
plugin: &PluginDependency,
) -> Option<PactPluginManifest>Lookup the plugin manifest in the global plugin manifest registry.