Module plugin_models

Module plugin_models 

Models for representing plugins

Structs

PactPlugin
Running plugin details
PactPluginManifest
Manifest of a plugin
PluginDependency
Plugin dependency
PluginInitRequest
PluginInitResponse
PluginInteractionConfig
Plugin configuration to add to the matching context for an interaction

Enums

PluginDependencyType
Type of plugin dependencies
PluginInterfaceVersion

Constants

ALL_INTERACTION_TYPES
Every interaction type a Pact file can record.

Traits

PactPluginRpc
Trait for the plugin init handshake only (used by anything that can handle the init message)
PluginInstance
Trait for a running plugin instance.

Functions

check_interaction_type_capability
Check that a plugin declared it can handle interactions of the given type.
interaction_type_capability
Capability name a V2 plugin declares to say it can handle interactions of this type.