PactPluginRpc

Trait PactPluginRpc 

pub trait PactPluginRpc {
Show 13 methods // Required methods fn init_plugin<'life0, 'async_trait>( &'life0 mut self, request: PluginInitRequest, ) -> Pin<Box<dyn Future<Output = Result<PluginInitResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn compare_contents<'life0, 'async_trait>( &'life0 self, request: CompareContentsRequest, ) -> Pin<Box<dyn Future<Output = Result<CompareContentsResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn configure_interaction<'life0, 'async_trait>( &'life0 self, request: ConfigureInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<ConfigureInteractionResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn generate_content<'life0, 'async_trait>( &'life0 self, request: GenerateContentRequest, ) -> Pin<Box<dyn Future<Output = Result<GenerateContentResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn start_mock_server<'life0, 'async_trait>( &'life0 self, request: StartMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<StartMockServerResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn shutdown_mock_server<'life0, 'async_trait>( &'life0 self, request: ShutdownMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<ShutdownMockServerResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn get_mock_server_results<'life0, 'async_trait>( &'life0 self, request: MockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<MockServerResults>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn prepare_interaction_for_verification<'life0, 'async_trait>( &'life0 self, request: VerificationPreparationRequest, ) -> Pin<Box<dyn Future<Output = Result<VerificationPreparationResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn verify_interaction<'life0, 'async_trait>( &'life0 self, request: VerifyInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<VerifyInteractionResponse>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; fn update_catalogue<'life0, 'async_trait>( &'life0 self, request: Catalogue, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>> where Self: 'async_trait, 'life0: 'async_trait; // Provided methods fn start_mock_server_v2<'life0, 'async_trait>( &'life0 self, request: StartMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<StartMockServerResponse>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn prepare_interaction_for_verification_v2<'life0, 'async_trait>( &'life0 self, request: VerificationPreparationRequest, ) -> Pin<Box<dyn Future<Output = Result<VerificationPreparationResponse>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... } fn verify_interaction_v2<'life0, 'async_trait>( &'life0 self, request: VerifyInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<VerifyInteractionResponse>> + Send + 'async_trait>> where Self: Sync + 'async_trait, 'life0: 'async_trait { ... }
}
Trait with remote-calling methods for a running plugin

Required Methods

fn init_plugin<'life0, 'async_trait>( &'life0 mut self, request: PluginInitRequest, ) -> Pin<Box<dyn Future<Output = Result<PluginInitResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Send an init request to the plugin process

fn compare_contents<'life0, 'async_trait>( &'life0 self, request: CompareContentsRequest, ) -> Pin<Box<dyn Future<Output = Result<CompareContentsResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Send a compare contents request to the plugin process

fn configure_interaction<'life0, 'async_trait>( &'life0 self, request: ConfigureInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<ConfigureInteractionResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Send a configure contents request to the plugin process

fn generate_content<'life0, 'async_trait>( &'life0 self, request: GenerateContentRequest, ) -> Pin<Box<dyn Future<Output = Result<GenerateContentResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Send a generate content request to the plugin

fn start_mock_server<'life0, 'async_trait>( &'life0 self, request: StartMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<StartMockServerResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Start a mock server

fn shutdown_mock_server<'life0, 'async_trait>( &'life0 self, request: ShutdownMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<ShutdownMockServerResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Shutdown a running mock server

fn get_mock_server_results<'life0, 'async_trait>( &'life0 self, request: MockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<MockServerResults>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Get the matching results from a running mock server

fn prepare_interaction_for_verification<'life0, 'async_trait>( &'life0 self, request: VerificationPreparationRequest, ) -> Pin<Box<dyn Future<Output = Result<VerificationPreparationResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Prepare an interaction for verification. This should return any data required to construct any request so that it can be amended before the verification is run.

fn verify_interaction<'life0, 'async_trait>( &'life0 self, request: VerifyInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<VerifyInteractionResponse>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Execute the verification for the interaction.

fn update_catalogue<'life0, 'async_trait>( &'life0 self, request: Catalogue, ) -> Pin<Box<dyn Future<Output = Result<()>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Updates the catalogue. This will be sent when the core catalogue has been updated (probably by a plugin loading).

Provided Methods

fn start_mock_server_v2<'life0, 'async_trait>( &'life0 self, request: StartMockServerRequest, ) -> Pin<Box<dyn Future<Output = Result<StartMockServerResponse>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Start a mock server using V2 structured interaction data (no pact JSON).

fn prepare_interaction_for_verification_v2<'life0, 'async_trait>( &'life0 self, request: VerificationPreparationRequest, ) -> Pin<Box<dyn Future<Output = Result<VerificationPreparationResponse>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Prepare an interaction for verification using V2 structured interaction data.

fn verify_interaction_v2<'life0, 'async_trait>( &'life0 self, request: VerifyInteractionRequest, ) -> Pin<Box<dyn Future<Output = Result<VerifyInteractionResponse>> + Send + 'async_trait>>
where Self: Sync + 'async_trait, 'life0: 'async_trait,

Execute the verification for the interaction using V2 structured interaction data.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors