Enum pact_plugin_driver::proto::body::ContentTypeHint
source · [−]#[repr(i32)]
pub enum ContentTypeHint {
Default,
Text,
Binary,
}Expand description
Enum of content type override. This is a hint on how the content type should be treated.
Variants
Default
Determine the form of the content using the default rules of the Pact implementation
Text
Contents must always be treated as a text form
Binary
Contents must always be treated as a binary form
Implementations