Struct pact_plugin_driver::proto::CompareContentsRequest
source · pub struct CompareContentsRequest {
pub expected: Option<Body>,
pub actual: Option<Body>,
pub allow_unexpected_keys: bool,
pub rules: HashMap<String, MatchingRules>,
pub plugin_configuration: Option<PluginConfiguration>,
}Expand description
Request to preform a comparison on an actual body given the expected one
Fields
expected: Option<Body>Expected body from the Pact interaction
actual: Option<Body>Actual received body
allow_unexpected_keys: boolIf unexpected keys or attributes should be allowed. Setting this to false results in additional keys or fields will cause a mismatch
rules: HashMap<String, MatchingRules>Map of expressions to matching rules. The expressions follow the documented Pact matching rule expressions
plugin_configuration: Option<PluginConfiguration>Additional data added to the Pact/Interaction by the plugin