Struct pact_plugin_driver::proto::CompareContentsResponse
source · pub struct CompareContentsResponse {
pub error: String,
pub type_mismatch: Option<ContentTypeMismatch>,
pub results: HashMap<String, ContentMismatches>,
}Expand description
Response to the CompareContentsRequest with the results of the comparison
Fields
error: StringError message if an error occurred. If this field is set, the remaining fields will be ignored and the verification marked as failed
type_mismatch: Option<ContentTypeMismatch>There was a mismatch with the types of content. If this is set, the results may not be set.
results: HashMap<String, ContentMismatches>Results of the match, keyed by matching rule expression