pub struct ConfigureInteractionResponse {
pub error: String,
pub interaction: Vec<InteractionResponse>,
pub plugin_configuration: Option<PluginConfiguration>,
}Expand description
Response to the configure/setup an interaction request
Fields
error: StringIf an error occurred. In this case, the other fields will be ignored/not set
interaction: Vec<InteractionResponse>The actual response if no error occurred.
plugin_configuration: Option<PluginConfiguration>Plugin specific data to be persisted in the pact file