Struct pact_plugin_driver::proto::ContentMismatch
source · pub struct ContentMismatch {
pub expected: Option<Vec<u8>>,
pub actual: Option<Vec<u8>>,
pub mismatch: String,
pub path: String,
pub diff: String,
pub mismatch_type: String,
}Expand description
A mismatch for an particular item of content
Fields
expected: Option<Vec<u8>>Expected data bytes
actual: Option<Vec<u8>>Actual data bytes
mismatch: StringDescription of the mismatch
path: StringPath to the item that was matched. This is the value as per the documented Pact matching rule expressions.
diff: StringOptional diff of the contents
mismatch_type: StringPart of the interaction that the mismatch is for: body, headers, metadata, etc.