Struct pact_plugin_driver::proto::GenerateContentRequest
source · pub struct GenerateContentRequest {
pub contents: Option<Body>,
pub generators: HashMap<String, Generator>,
pub plugin_configuration: Option<PluginConfiguration>,
pub test_context: Option<Struct>,
pub test_mode: i32,
pub content_for: i32,
}Expand description
Request to generate the contents using any defined generators
Fields
contents: Option<Body>Original contents
generators: HashMap<String, Generator>Generators to apply
plugin_configuration: Option<PluginConfiguration>Additional data added to the Pact/Interaction by the plugin
test_context: Option<Struct>Context data provided by the test framework
test_mode: i32content_for: i32Implementations
sourceimpl GenerateContentRequest
impl GenerateContentRequest
sourcepub fn test_mode(&self) -> TestMode
pub fn test_mode(&self) -> TestMode
Returns the enum value of test_mode, or the default if the field is set to an invalid enum value.
sourcepub fn set_test_mode(&mut self, value: TestMode)
pub fn set_test_mode(&mut self, value: TestMode)
Sets test_mode to the provided enum value.
sourcepub fn content_for(&self) -> ContentFor
pub fn content_for(&self) -> ContentFor
Returns the enum value of content_for, or the default if the field is set to an invalid enum value.
sourcepub fn set_content_for(&mut self, value: ContentFor)
pub fn set_content_for(&mut self, value: ContentFor)
Sets content_for to the provided enum value.