Struct pact_plugin_driver::proto::InteractionResponse
source · pub struct InteractionResponse {
pub contents: Option<Body>,
pub rules: HashMap<String, MatchingRules>,
pub generators: HashMap<String, Generator>,
pub message_metadata: Option<Struct>,
pub plugin_configuration: Option<PluginConfiguration>,
pub interaction_markup: String,
pub interaction_markup_type: i32,
pub part_name: String,
pub metadata_rules: HashMap<String, MatchingRules>,
pub metadata_generators: HashMap<String, Generator>,
}Expand description
Response to the configure/setup an interaction request
Fields
contents: Option<Body>Contents for the interaction
rules: HashMap<String, MatchingRules>All matching rules to apply
generators: HashMap<String, Generator>Generators to apply
message_metadata: Option<Struct>For message interactions, any metadata to be applied
plugin_configuration: Option<PluginConfiguration>Plugin specific data to be persisted in the pact file
interaction_markup: StringMarkdown/HTML formatted text representation of the interaction
interaction_markup_type: i32part_name: StringDescription of what part this interaction belongs to (in the case of there being more than one, for instance, request/response messages)
metadata_rules: HashMap<String, MatchingRules>All matching rules to apply to any message metadata
metadata_generators: HashMap<String, Generator>Generators to apply to any message metadata
Implementations
sourceimpl InteractionResponse
impl InteractionResponse
sourcepub fn interaction_markup_type(&self) -> MarkupType
pub fn interaction_markup_type(&self) -> MarkupType
Returns the enum value of interaction_markup_type, or the default if the field is set to an invalid enum value.
sourcepub fn set_interaction_markup_type(&mut self, value: MarkupType)
pub fn set_interaction_markup_type(&mut self, value: MarkupType)
Sets interaction_markup_type to the provided enum value.