Struct pact_plugin_driver::proto::MockServerResult
source · pub struct MockServerResult {
pub path: String,
pub error: String,
pub mismatches: Vec<ContentMismatch>,
}Expand description
Result of a request that the mock server received
Fields
path: Stringservice + method that was requested
error: StringIf an error occurred trying to handle the request
mismatches: Vec<ContentMismatch>Any mismatches that occurred