Module plugin_host_server

Module plugin_host_server 

Generated server implementations.

Structs

PluginHostServer
Driver-side service implemented by the driver and called by plugins

Constants

SERVICE_NAME
Generated gRPC service name

Traits

PluginHost
Generated trait containing gRPC methods that should be implemented for use with PluginHostServer.