pub struct FieldValue {
pub value: Option<Value>,
}Expand description
A single value being matched or generated at the field/element level.
Each type Pact’s matching rules discriminate has its own arm, rather than everything
JSON-representable sharing a google.protobuf.Value. That type carries a single number type (a
double), which would make integer and decimal indistinguishable and type wrong between a
whole number and a decimal - and these are exactly the rules whose job is to check the runtime
type of a value. Binary data has its own arm for the same reason: so it never has to be
stringified into a form it does not fit.
See proposal 006 (Field-level matchers and generators).
Fields
value: Option<Value>Trait Implementations
Sourceimpl Clone for FieldValue
impl Clone for FieldValue
Sourcefn clone(&self) -> FieldValue
fn clone(&self) -> FieldValue
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for FieldValue
impl Debug for FieldValue
Sourceimpl Default for FieldValue
impl Default for FieldValue
Sourceimpl Message for FieldValue
impl Message for FieldValue
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
self.Sourceimpl PartialEq for FieldValue
impl PartialEq for FieldValue
impl StructuralPartialEq for FieldValue