pub struct HostCompareContentsRequest {
pub entry_key: String,
pub request: Option<CompareContentsRequest>,
}Expand description
Callback request from a plugin to invoke a content matcher capability - host-provided or owned by another plugin - resolved by catalogue entry key. See proposal 007 (Driver-plugin callback model).
Fields
entry_key: StringCatalogue entry key identifying the capability to invoke, e.g. “xml” for content-matcher/xml
request: Option<CompareContentsRequest>The comparison request, in the same shape as PactPlugin.CompareContents