pub struct HostGenerateContentRequest {
pub entry_key: String,
pub request: Option<GenerateContentRequest>,
}Expand description
Callback request from a plugin to invoke a content generator capability - host-provided or owned by another plugin - resolved by catalogue entry key. See proposal 007 (Driver-plugin callback model).
Fields
entry_key: StringCatalogue entry key identifying the capability to invoke, e.g. “xml” for content-generator/xml
request: Option<GenerateContentRequest>The generation request, in the same shape as PactPlugin.GenerateContent