pub struct MatchFieldResponse {
pub error: String,
pub mismatches: Vec<ContentMismatch>,
}Expand description
Response to the MatchFieldRequest with the result of applying the rule
Fields
error: StringError message if the rule could not be applied at all. If this field is set, the remaining fields will be ignored and the verification marked as failed
mismatches: Vec<ContentMismatch>Mismatches found. An empty list means the value matched. A mismatch with an empty path is reported against the path from the request