Struct pact_plugin_driver::repository::PluginEntry
source · pub struct PluginEntry {
pub name: String,
pub latest_version: String,
pub versions: Vec<PluginVersion>,
}Expand description
Struct to store the plugin version entries
Fields
name: StringName of the plugin
latest_version: StringLatest version
versions: Vec<PluginVersion>All the plugin versions
Implementations
sourceimpl PluginEntry
impl PluginEntry
sourcepub fn new(
manifest: &PactPluginManifest,
source: &ManifestSource
) -> PluginEntry
pub fn new( manifest: &PactPluginManifest, source: &ManifestSource ) -> PluginEntry
Create a new plugin entry from the provided manifest and source
sourcepub fn add_version(
&mut self,
manifest: &PactPluginManifest,
source: &ManifestSource
)
pub fn add_version( &mut self, manifest: &PactPluginManifest, source: &ManifestSource )
Adds the data from the plugin manifest as a version to the index