Models for representing plugins
Structs
- Pact
Plugin - Running plugin details
- Pact
Plugin Manifest - Manifest of a plugin
- Plugin
Dependency - Plugin dependency
- Plugin
Init Request - Plugin
Init Response - Plugin
Interaction Config - Plugin configuration to add to the matching context for an interaction
Enums
- Plugin
Dependency Type - Type of plugin dependencies
- Plugin
Interface Version
Constants
- ALL_
INTERACTION_ TYPES - Every interaction type a Pact file can record.
Traits
- Pact
Plugin Rpc - Trait for the plugin init handshake only (used by anything that can handle the init message)
- Plugin
Instance - Trait for a running plugin instance.
Functions
- check_
interaction_ type_ capability - Check that a plugin declared it can handle interactions of the given type.
- interaction_
type_ capability - Capability name a V2 plugin declares to say it can handle interactions of this type.