Module plugin_models

Module plugin_models 

Models for representing plugins

Structs

PactPlugin
Running plugin details
PactPluginManifest
Manifest of a plugin
PluginDependency
Plugin dependency
PluginInitRequest
PluginInitResponse
PluginInteractionConfig
Plugin configuration to add to the matching context for an interaction

Enums

PluginDependencyType
Type of plugin dependencies
PluginInterfaceVersion

Traits

PactPluginRpc
Trait for the plugin init handshake only (used by anything that can handle the init message)
PluginInstance
Trait for a running plugin instance.